<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>DirectoryMenu</name>
    <message>
        <location filename="../directorymenu.cpp" line="126"/>
        <source>Open</source>
        <translation>Aç</translation>
    </message>
    <message>
        <location filename="../directorymenu.cpp" line="130"/>
        <source>Open in terminal</source>
        <translation>Terminal&apos;de aç</translation>
    </message>
</context>
<context>
    <name>DirectoryMenuConfiguration</name>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="14"/>
        <source>Directory Menu Settings</source>
        <translation>Dizin Menü Ayarları</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="20"/>
        <source>Appearance</source>
        <translation>Görünüm</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="26"/>
        <source>Base directory:</source>
        <translation>Temel dizin:</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="39"/>
        <source>BaseDirectoryName</source>
        <translation>Temel Dizin Adı</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="46"/>
        <source>Icon:</source>
        <translation>Simge:</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="66"/>
        <source>Label</source>
        <translation>Etiket</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="86"/>
        <source>Button style</source>
        <translation>Düğme biçemi</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="103"/>
        <source>Terminal</source>
        <translation>Terminal</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="96"/>
        <location filename="../directorymenuconfiguration.cpp" line="131"/>
        <source>Choose Default Terminal</source>
        <translation>Varsayılan Terminal&apos;i Seç</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="54"/>
        <source>Only icon</source>
        <translation>Sadece simge</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="55"/>
        <source>Only text</source>
        <translation>Sadece metin</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="56"/>
        <source>Icon and text</source>
        <translation>Simge ve metin</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="115"/>
        <source>Choose Base Directory</source>
        <translation>Temel Dizini Seç</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="164"/>
        <source>Choose Icon</source>
        <translation>Simge Seç</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="164"/>
        <source>Icons (*.png *.xpm *.jpg *.svg)</source>
        <translation>Simgeler (*.png *.xpm *.jpg *.svg)</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="188"/>
        <source>Choose Label</source>
        <translation>Etiket Seç</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="189"/>
        <source>Label:</source>
        <translation>Etiket:</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="173"/>
        <source>Directory Menu</source>
        <translation>Dizin Menüsü</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="173"/>
        <source>An error occurred while loading the icon.</source>
        <translation>Simge yüklenirken hata oluştu.</translation>
    </message>
</context>
</TS>
